@@ -405,7 +405,11 @@ class Source():
             self.name = self.name.replace("https://ppa.launchpadcontent.net/", "")
             self.name = self.name.replace("/ubuntu", "")
             self.name = self.name.replace("/ppa", "")
-            self.ppa_owner, self.ppa_name = self.name.split("/")
+            self.ppa_owner = self.name.split("/")[0]
+            try:
+                self.ppa_name = self.name.split("/")[1]
+            except IndexError:
+                self.ppa_name = "ppa"
 
         # set UI name
         uris = " ".join(self.repo.uris)
